@@ -3,7 +3,7 @@
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -29,9 +29,9 @@ namespace crypt
 
 mobius::bytearray pkcs5_unpad (const mobius::bytearray&);
 
-mobius::bytearray pbkdf1 (const mobius::bytearray&, const mobius::bytearray&, std::uint32_t, std::uint16_t, const std::string& = "sha1");
+mobius::bytearray pbkdf1 (const std::string&, const mobius::bytearray&, const mobius::bytearray&, std::uint32_t, std::uint16_t);
 
-mobius::bytearray pbkdf2_hmac (const mobius::bytearray&, const mobius::bytearray&, std::uint32_t, std::uint16_t, const std::string& = "sha1");
+mobius::bytearray pbkdf2_hmac (const std::string&, const mobius::bytearray&, const mobius::bytearray&, std::uint32_t, std::uint16_t);
 
 } // namespace crypt
 } // namespace mobius
