@@ -1,9 +1,9 @@
-#ifndef __MOBIUS_EXCEPTION_H__
-#define __MOBIUS_EXCEPTION_H__
+#ifndef MOBIUS_EXCEPTION_H
+#define MOBIUS_EXCEPTION_H
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -22,7 +22,8 @@
 
 namespace mobius
 {
-const std::string exception_msg (const char *, const char *, std::size_t, const char *) noexcept;
+std::string exception_msg (const char *, const char *, std::size_t, const char *);
+std::string exception_msg (const std::string&, const std::string&, std::size_t, std::string);
 } // namespace mobius
 
 #endif
