@@ -44,7 +44,7 @@ PyMobius_Pod_Data_Check (PyObject *pyobj)
 //! \return new data object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
-PyMobius_Pod_Data_from_cpp (mobius::pod::data obj)
+PyMobius_Pod_Data_from_cpp (const mobius::pod::data& obj)
 {
   PyObject *ret = nullptr;
   
@@ -121,6 +121,9 @@ PyMobius_Pod_Data_from_python (PyObject *py_value)
   else if (PyList_Check (py_value))
     data = PyMobius_Pod_List_from_python (py_value);
 
+  else if (PyTuple_Check (py_value))
+    data = PyMobius_Pod_List_from_python (py_value);
+
   else if (PyDict_Check (py_value))
     data = PyMobius_Pod_Map_from_python (py_value);
 
